@@ -16,11 +16,13 @@ from .getUserId import getUserId
 from .addRole import addRole
 from .getUserId import getUserId
 from .addUser import addUser
+from .addFx import addFx
 from .createAccount import createAccount
 from .getBanks import getBanks
 from .getAccountsHeld import getAccountsHeld
 from .getAccount import getAccountById
 from .deleteBranches import deleteBranches
+from .getUserIdByUsername import getUserIdByUsername
 import pprint
 
 @click.group()
@@ -114,6 +116,16 @@ def getuserid():
   else:
     exit(req.text)
 
+@cli.command(help="📋 Get user id by username")
+@click.option('--username', prompt=True)
+def getuseridbyusername(username):
+  req = getUserIdByUsername(username=username)
+  if req.status_code == 201 or req.status_code == 200:
+    user_id = json.loads(req.text)['user_id']
+    click.echo({'user_id': user_id})
+  else:
+    exit(req.text)
+
 @cli.command(help="🏦 Get list of banks")
 def getbanks():
   req = getBanks()
@@ -162,27 +174,46 @@ def adduser(username, email, password, firstname, lastname):
 @click.option('--userid', prompt=True, help="Use 'obp getuserid' to find it")
 @click.option('--accountid', default="abc123", prompt=True, help="Your choice of account id")
 @click.option('--label', default="Label", prompt=True)
-@click.option('--type', default="CURRENT", prompt=True, hide_input=True)
+@click.option('--type', default="CURRENT", prompt=True)
 @click.option('--currency', default="EUR", prompt=True)
-@click.option('--balance', default="0", prompt=True)
 @click.option('--branchid', default="1234", prompt=True)
 @click.option('--bankid', prompt=True, help="Try getbanks")
-def addaccount(userid, accountid, label, type, currency, balance,
-               branchid, bankid):
+def addaccount(userid, accountid, label, type, currency, branchid, bankid):
 
   req = createAccount(userid=userid, label=label, type=type,
-                      currency=currency, balance=balance,
-                      bankid=bankid, branchid=branchid,
-                      accountid=accountid)
+                      currency=currency, bankid=bankid, 
+                      branchid=branchid, accountid=accountid)
   if req.status_code == 201 or req.status_code == 200:
     click.echo(req.text)
   else:
     exit(req.text)
 
 @cli.command(help="🚧 Add a role for current user")
-@click.option('--role-name', required=True)
-def addrole(role_name):
-  req = addRole(role=role_name, require_bank_id=False)
+@click.option('--role-name', required=True, help="Name of the role/entitelment")
+@click.option('--bank-id', required=False, help="Some roles need a bank id")
+@click.option('--user-id', required=False, help="Add role to a differnt user")
+def addrole(role_name, bank_id=None, user_id=None):
+  if bank_id is None:
+    req = addRole(role=role_name, user_id=user_id)
+  else:
+    req = addRole(role=role_name, bank_id=bank_id, user_id=user_id)
+  if req.status_code == 201 or req.status_code == 200:
+    click.echo(req.text)
+  else:
+    exit(req.text)
+
+@cli.command(help="📉 Add exchange rate (FX)")
+@click.option('--bank-id', required=True, prompt=True)
+@click.option('--from-currency', required=True, prompt=True)
+@click.option('--to-currency', required=True, prompt=True)
+@click.option('--conversion-value', required=True, prompt=True)
+@click.option('--inverse-conversion-value', required=True, prompt=True)
+@click.option('--effective-date', required=True, prompt=True, 
+              help="2017-09-19T00:00:00Z")
+def addfx(bank_id, from_currency, to_currency, conversion_value,
+          inverse_conversion_value, effective_date):
+  req = addFx(bank_id, from_currency, to_currency, conversion_value,
+              inverse_conversion_value, effective_date)
   if req.status_code == 201 or req.status_code == 200:
     click.echo(req.text)
   else:
