@@ -19,7 +19,7 @@ def write_config(NAME, VALUE):
   with open(os.path.join(confDir, NAME), 'w') as fp:
     fp.write(str(VALUE))
 
-def get_config(NAME):
+def get_config(NAME, default=None, allow_stdin=True):
   path = os.path.join(confDir, NAME)
   if os.path.isfile(path) is False:
     init_config_dir()
@@ -31,8 +31,11 @@ def get_config(NAME):
       with open(os.path.join(confDir, NAME)) as fp:
         return fp.read()
     except FileNotFoundError:
-      return input('{} -->'.format(NAME))
-  return False
+      if allow_stdin:
+        return input('{} -->'.format(NAME))
+  if default is not None:
+    return default
+  return None
 
 def set_obp_api_host(OBP_API_HOST):
     write_config("OBP_API_HOST", OBP_API_HOST)
@@ -40,6 +43,9 @@ def set_obp_api_host(OBP_API_HOST):
 def set_obp_username(OBP_USERNAME):
     write_config("OBP_USERNAME", OBP_USERNAME)
 
+def set_obp_user_id(OBP_USER_ID):
+    write_config("OBP_USER_ID", OBP_USER_ID)
+
 def set_obp_password(OBP_PASSWORD):
     write_config("OBP_PASSWORD", OBP_PASSWORD)
 
